..
  class.rst

ardt.datasets.ascertain.AscertainDataset
========================================

.. currentmodule:: ardt.datasets.ascertain

.. autoclass:: AscertainDataset
    :members:
    :show-inheritance:
    :inherited-members:
